/* NAME:
 *	assert.h - enforce assertions
 *
 * DESCRIPTION:
 *	If syslog.h has been included before us, we syslog() as well
 *	as printing to stderr.  The macro ASSERT() defaults to
 *	abort()ing the process, while assert() simply exit()s
 * 
 * RCSid:
 *	$Id: assert.h,v 1.2 1997/03/02 13:27:39 sjg Exp $
 */
# ifndef NDEBUG
# ifdef __STDC__
#   define _str(x) #x
# else
#   define _str(x) "x"
# endif
#ifdef LOG_NOTICE
# define _assert(ex,act)    {if (!(ex)){syslog(LOG_ERR, "Assertion (%s) failed: file \"%s\", line %d\n", _str(ex), __FILE__, __LINE__);(void)fprintf(stderr,"Assertion (%s) failed: file \"%s\", line %d\n", _str(ex), __FILE__, __LINE__);act;}}
#else
# define _assert(ex,act)    {if (!(ex)){(void)fprintf(stderr,"Assertion (%s) failed: file \"%s\", line %d\n", _str(ex), __FILE__, __LINE__);act;}}
#endif
# define assert(ex)     _assert(ex,exit(1))
/*
 * On some systems abort() achieves nothing, so
 * we need to make this kill(getpid(), 6)
 */
#ifndef ABORT
# define ABORT kill(getpid(), 6)
#endif
# define ASSERT(ex)     _assert(ex,ABORT)
# else
/* just eat them */
# define _assert(ex)
# define assert(ex)
# define ASSERT(ex)
# endif
